This package is developed as the common interface for local DB and GUI of
non-electrical test.

**Note**

The dbinterface assumes that the local DB is built at port=27017, if not, pelase
edit connectDB().
